#
# spec file for package ghc-assoc
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name assoc
%global pkgver %{pkg_name}-%{version}
Name:           ghc-%{pkg_name}
Version:        1.1.1
Release:        1.5
Summary:        Swap and assoc: Symmetric and Semigroupy Bifunctors
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-rpm-macros
ExcludeArch:    %{ix86}

%description
Provides generalisations of 'swap :: (a,b) -> (b,a)' and 'assoc :: ((a,b),c) ->
(a,(b,c))' to 'Bifunctor's supporting similar operations (e.g.
'Either', 'These').

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sun May 12 2024 Peter Simons <psimons@suse.com>
- Update assoc to version 1.1.1.
  [#]# 1.1.1
  - Drop support for GHC prior GHC-8.6.5
* Wed Oct  4 2023 Peter Simons <psimons@suse.com>
- Update assoc to version 1.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Jun 13 2023 Peter Simons <psimons@suse.com>
- Update assoc to version 1.1.
  [#]# 1.1
  - Depend on `bifunctor-classes-compat` only.
    Instances for types defined in `bifunctors` package are moved there.
    With this change `assoc` only depends on `base` and `tagged`.
  - Mark modules as explicitly Safe
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Mon Mar 13 2023 Peter Simons <psimons@suse.com>
- Update assoc to version 1.0.2 revision 4.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Aug 10 2022 Peter Simons <psimons@suse.com>
- Update assoc to version 1.0.2 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Nov  1 2021 psimons@suse.com
- Update assoc to version 1.0.2 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Feb 15 2021 psimons@suse.com
- Update assoc to version 1.0.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Mon Aug 10 2020 psimons@suse.com
- Update assoc to version 1.0.2.
  [#]# 1.0.2
  - Add 'Swap' instances for more n-tuples
* Tue Jun  9 2020 psimons@suse.com
- Add assoc at version 1.0.1.
